/****************************************************************
 *								*
 * Copyright (c) 2001-2018 Fidelity National Information	*
 * Services, Inc. and/or its subsidiaries. All rights reserved.	*
 *								*
 *	This source code contains the intellectual property	*
 *	of its copyright holder(s), and is made available	*
 *	under a license.  If you do not know the terms of	*
 *	the license, please stop and do not read further.	*
 *								*
 ****************************************************************/

#ifndef BML_FIND_BUSY_H_INCLUDED
#define BML_FIND_BUSY_H_INCLUDED

int4 bml_find_busy(int4 hint, uchar_ptr_t base_addr, int4 total_blks);

#endif
